declare module "enscript-reusables" {
	import React from "react";

	interface BreadcrumbItem {
		text: string;
		link: string;
	}

	interface BreadcrumbsProps {
		crumbs: Array<BreadcrumbItem>;
	}

	export const Breadcrumbs: React.FunctionComponent<BreadcrumbsProps>;

	enum CheckableFieldOrientation {
		vertical = "vertical",
		horizontal = "horizontal"
	}

	interface CheckableItem {
		label: string;
		value: any;
	}

	interface CheckGroupProps {
		label: string;
		options: Array<CheckableItem>;
		values: Array<string>;
		orientation: CheckableFieldOrientation;
		onChange: Function;
	}

	export const CheckGroup: React.FunctionComponent<CheckGroupProps>;

	interface ConfirmModalProps {
		classes: Array<string>;
		content: Array<string>;
		isLoading: boolean;
		asDialog: boolean;
		expandOnRender: boolean;
		onConfirm: Function;
	}

	export const ConfirmModal: React.FunctionComponent<ConfirmModalProps>;

	interface DatePickerProps {
		className: string;
		dateFormat: string;
		displayDateFormat: string;
		value: string;
		onChange: Function;
	}

	export const DatePicker: React.FunctionComponent<DatePickerProps>;

	interface FileFieldProps {
		className: string;
		accept: Array<string>;
		maxFileSize: number;
		onChange: Function;
	}

	export const FileField: React.FunctionComponent<FileFieldProps>;

	interface FlashItem {
		id: string;
		level: string;
		message: string;
	}

	interface FlashProps {
		items: Array<FlashItem>;
		onRemoveFlash: Function;
	}

	export const Flash: React.FunctionComponent<FlashProps>;

	export const FormCheckGroup: React.FunctionComponent;
	export const FormDatePicker: React.FunctionComponent;
	export const FormFileField: React.FunctionComponent;
	export const FormInputField: React.FunctionComponent;
	export const FormNumberField: React.FunctionComponent;
	export const FormRadioGroup: React.FunctionComponent;
	export const FormSelectField: React.FunctionComponent;
	export const FormTextField: React.FunctionComponent;

	interface withFormParams {
		name: string;
		required: Array<string>;
		accessible: Array<string>;
		validateSecondary: Function;
		initialValues: Object;
	}

	interface HOCs {
		withForm(params: withFormParams): Function;
		withQueryParams(Element): Function;
	}

	export const HOCs: HOCs;

	interface Hooks {
		useWindowSize(callback: Function): void;
		useWindowSizes(callback: Function): void;
	}

	export const Hooks: Hooks;

	interface RadioGroupProps {
		label: string;
		options: Array<CheckableItem>;
		value: string;
		orientation: CheckableFieldOrientation;
		onChange: Function;
	}

	export const RadioGroup: React.FunctionComponent<RadioGroupProps>;

	interface ItemAttr {
		label: string;
		value: string;
	}

	interface ListRendererProps {
		items: Array<Object>;
		attrs: Array<ItemAttr>;
		renderCustomData: Function;
		renderCustomUI: Function;
		redirect: string;
		customUIContainerClass: string;
	}

	export const ListRenderer: React.FunctionComponent<ListRendererProps>;

	interface LoaderProps {
		loaderImage: any;
	}

	export const Loader: React.FunctionComponent<LoaderProps>;

	interface LoaderButtonProps {
		className: string;
		isLoading: boolean;
	}

	export const LoaderButton: React.FunctionComponent<LoaderButtonProps>;

	interface ObjectViewerProps {
		object: Object;
		attrs: Array<ItemAttr>;
		renderCustomData: Function;
	}

	export const ObjectViewer: React.FunctionComponent<ObjectViewerProps>;

	export const Overlay: React.FunctionComponent;

	interface PageContainerProps {
		noTopbar: boolean;
		asContainer: boolean;
	}

	export const PageContainer: React.FunctionComponent<PageContainerProps>;

	interface PageHeaderProps {
		title: string;
		subtitle: string;
	}

	export const PageHeader: React.FunctionComponent<PageHeaderProps>;

	interface PaginationProps {
		page: number;
		total: number;
		size: number;
		onNext: Function;
		onPrev: Function;
	}

	export const Pagination: React.FunctionComponent<PaginationProps>;

	interface SearchInputProps {
		className: string;
		placeholder: string;
		onChange: Function;
	}

	export const SearchInput: React.FunctionComponent<SearchInputProps>;

	interface TabProps {
		labels: Array<string>;
		index: number;
		setIndex: Function;
	}

	export const Tab: React.FunctionComponent<TabProps>;

    interface AxiosResponse {}
    
    interface ReduxFormInputWrapperConfig {
        className: string;
    }

	interface Utils {
		createUrl(apiUrl: string, path: string): string;
		successMessage(response: AxiosResponse, fallbackMsg: string): string;
        errorMessage(error, fallbackMsg: string): string;
        reduxFormInputWrapper(Component, config: ReduxFormInputWrapperConfig): object;
	}

	interface InviteAgentModalProps {
		isLoading: boolean;
		roles: Array<String>;
		onInvite: Function;
	}

	export const InviteAgentModal: React.FunctionComponent<InviteAgentModalProps>;

	export const utils: Utils;
}
