import path from "path";
import sass from "rollup-plugin-sass";
import replace from "rollup-plugin-replace";
import resolve from "rollup-plugin-node-resolve";
import commonjs from "rollup-plugin-commonjs";
import embedCSS from "rollup-plugin-embed-css";
import { terser } from "rollup-plugin-terser";
import babel from "rollup-plugin-babel";
import autoprefixer from "autoprefixer";
import svg from "rollup-plugin-svg";
import postcss from "postcss";

const NODE_ENV = "development";

export default {
	input: path.resolve(__dirname, "./src/index.js"),
	output: {
		file: path.resolve(__dirname, "./dist/bundle.js"),
		format: "cjs"
	},
	plugins: [
		replace({ "process.env.NODE_ENV": JSON.stringify(NODE_ENV) }),
		babel({ exclude: "node_modules/**" }),
		resolve({ extensions: [".js", ".jsx", ".scss", ".svg", ".css"] }),
		svg(),
		commonjs({
			namedExports: { "node_modules/react-is/index.js": ["isValidElementType", "isContextConsumer"] }
		}),
		sass({
			insert: true,
			processor: css =>
				postcss([autoprefixer])
					.process(css, { from: "undefined" })
					.then(result => result.css)
		}),
		embedCSS(),
		terser()
	],
	external: ["moment", "react", "react-dom", "react-router-dom", "react-redux", "redux", "redux-form"]
};
