import "./index.scss";
import React from "react";
import PropTypes from "prop-types";

export function CheckGroup({ label, options, values, orientation = "horizontal", noLabel, onChange }) {
	const interceptOnChange = value => {
		if (values.includes(value)) onChange(values.filter(v => v != value));
		else onChange([...values, value]);
	};

	const interceptOnKeyPress = (e, value) => {
		if (e.keyCode == 13 || e.keyCode == 32) {
			// If the spacebar or enter key is pressed
			interceptOnChange(value);
		}
	};

	return (
		<div className={`check-group ${orientation == "vertical" ? "vertical" : ""}`}>
			{!noLabel && <label className="check-group-label">{label}</label>}

			{options.map(({ label, value }, i) => {
				const checked = values.includes(value);

				return (
					<label
						key={`check-box${i}`}
						className="check-box"
						onClick={() => interceptOnChange(value)}
						onKeyDown={e => interceptOnKeyPress(e, value)}
						tabIndex={0}
					>
						<span className={`indicator ${checked ? "checked" : ""}`} />
						<label>{label}</label>
					</label>
				);
			})}
		</div>
	);
}

CheckGroup.propTypes = {
	label: PropTypes.string,
	options: PropTypes.arrayOf(
		PropTypes.shape({
			label: PropTypes.string,
			value: PropTypes.any
		})
	),
	values: PropTypes.array,
	orientation: PropTypes.oneOf(["horizontal", "vertical"]),
	noLabel: PropTypes.bool,
	onChange: PropTypes.func
};
