import React, { useState } from "react";
import { storiesOf } from "@storybook/react";
import { action } from "@storybook/addon-actions";
import { CheckGroup } from "./index.jsx";

const withValueProps = {
	label: "Label",
	options: [{ label: "A", value: "a" }, { label: "B", value: "b" }, { label: "C", value: "c" }, { label: "D", value: "d" }]
};

const isVerticalProps = {
	...withValueProps,
	orientation: "vertical"
};

storiesOf("CheckGroup", module)
	.addDecorator(story => <div style={{ padding: "30px" }}>{story()}</div>)
	.add("default", () => {
		const CheckGroupHolder = function() {
			const [values, setValues] = useState([]);
			const onSetValues = value => {
				setValues(value);
				action("Changed")(value);
			};
			return <CheckGroup {...withValueProps} values={values} onChange={onSetValues} />;
		};

		return <CheckGroupHolder />;
	})
	.add("is vertical", () => {
		const CheckGroupHolder = function() {
			const [values, setValues] = useState([]);
			const onSetValues = value => {
				setValues(value);
				action("Changed")(value);
			};
			return <CheckGroup {...isVerticalProps} values={values} onChange={onSetValues} />;
		};

		return <CheckGroupHolder />;
	})
	.add("with no label", () => {
		const CheckGroupHolder = function() {
			const [values, setValues] = useState([]);
			const onSetValues = value => {
				setValues(value);
				action("Changed")(value);
			};
			return <CheckGroup {...isVerticalProps} values={values} onChange={onSetValues} noLabel />;
		};

		return <CheckGroupHolder />;
	});
