import "./index.scss";
import PropTypes from "prop-types";
import React, { useState } from "react";
import { LoaderButton } from "../loader-button";
import { Overlay } from "../overlay";

export const ConfirmModal = ({ classes, content, isLoading, asDialog, expandOnRender, onConfirm }) => {
	const [expanded, setExpanded] = useState(expandOnRender);

	return (
		<span className="confirm-modal">
			{!expanded && (
				<button type="button" className={`trigger ${(classes && classes[0]) || "btn btn-primary"}`} onClick={() => setExpanded(true)}>
					{content[0]}
				</button>
			)}

			{expanded && !asDialog && (
				<button
					type="button"
					className={`cancel ${(classes && classes[2]) || "btn btn-link"}`}
					onClick={() => setExpanded(false)}
					disabled={isLoading}
				>
					{content[2] || "Cancel"}
				</button>
			)}

			{expanded && !asDialog && (
				<LoaderButton
					type="button"
					className={`confirm ${(classes && classes[1]) || "btn btn-primary"}`}
					onClick={onConfirm}
					isLoading={isLoading}
				>
					{content[1] || "Confirm"}
				</LoaderButton>
			)}

			{expanded && asDialog && (
				<Overlay>
					<div className="card">
						<div className="card-body">
							<p>{content[1] || "Confirm"}</p>

							<div className="d-flex">
								<LoaderButton
									type="button"
									className={`confirm ${(classes && classes[1]) || "btn btn-primary btn-sm"}`}
									onClick={onConfirm}
									isLoading={isLoading}
								>
									Confirm
								</LoaderButton>
								&nbsp;
								<button
									type="button"
									className={`cancel ${(classes && classes[2]) || "btn btn-link btn-sm"}`}
									onClick={() => setExpanded(false)}
									disabled={isLoading}
								>
									{content[2] || "Cancel"}
								</button>
							</div>
						</div>
					</div>
				</Overlay>
			)}
		</span>
	);
};

ConfirmModal.propTypes = {
	classes: PropTypes.arrayOf(PropTypes.string),
	content: PropTypes.arrayOf(PropTypes.string),
	expandOnRender: PropTypes.bool,
	isLoading: PropTypes.bool,
	asDialog: PropTypes.bool,
	onConfirm: PropTypes.func
};
