import "./index.scss";
import React from "react";
import PT from "prop-types";

export const Flash = ({ items, onRemoveFlash }) => {
	return (
		<div className="flash">
			{items.map(item => (
				<FlashItem key={item.id} item={item} removeFlash={onRemoveFlash} />
			))}
		</div>
	);
};

const FlashItem = ({ item: { id, level, message }, removeFlash }) => {
	return (
		<div key={id} className={`alert alert-${level}`}>
			{message}
			<button className="close" onClick={() => removeFlash(id)}>
				<span aria-hidden="true">&times;</span>
			</button>
		</div>
	);
};

FlashItem.propTypes = {
	item: PT.shape({
		id: PT.string,
		level: PT.string,
		message: PT.string
	}),
	removeFlash: PT.func
};

Flash.propTypes = {
	items: PT.arrayOf(
		PT.shape({
			id: PT.string,
			level: PT.string,
			message: PT.string
		})
	),
	onRemoveFlash: PT.func
};
