import React from "react";
import { Field } from "redux-form";
import { storiesOf } from "@storybook/react";
import { action } from "@storybook/addon-actions";
import { StoreProvider } from "../../_decorators";
import { FormCheckGroup } from "./index.jsx";
import { HOCs } from "../../hocs/index.js";

storiesOf("FormCheckGroup", module)
	.addDecorator(story => (
		<StoreProvider>
			<div style={{ padding: "30px" }}>{story()}</div>
		</StoreProvider>
	))
	.add("default", () => {
		// eslint-disable-next-line react/prop-types
		const Holder = function({ handleSubmit }) {
			const interceptSubmit = values => {
				action("CheckGroupForm submitted")(values);
			};

			return (
				<form onSubmit={handleSubmit(interceptSubmit)}>
					{/* You can pass any attribute of <CheckGroup /> as attributes of the <Field /> */}
					<Field
						component={FormCheckGroup}
						name="prop"
						label="CheckGroup Property"
						options={[
							{ label: "A", value: "A" },
							{ label: "B", value: "B" },
							{ label: "C", value: "C" },
							{ label: "D", value: "D" },
							{ label: "E", value: "E" },
							{ label: "F", value: "F" }
						]}
					/>
					<button className="btn btn-primary">Submit</button>
				</form>
			);
		};

		const FormWrapper = HOCs.withForm({
			name: "DatePickerForm",
			required: []
		})(Holder);

		return <FormWrapper />;
	});
