import React from "react";
import { Field } from "redux-form";
import { storiesOf } from "@storybook/react";
import { action } from "@storybook/addon-actions";
import { StoreProvider } from "../../_decorators";
import { FormSelectField } from "./index";
import { HOCs } from "../../hocs";

storiesOf("FormSelectField", module)
	.addDecorator(story => (
		<StoreProvider>
			<div style={{ padding: "30px" }}>{story()}</div>
		</StoreProvider>
	))
	.add("default", () => {
		// eslint-disable-next-line react/prop-types
		const Holder = function({ handleSubmit }) {
			const interceptSubmit = values => {
				action("SelectFieldForm submitted")(values);
			};

			return (
				<form onSubmit={handleSubmit(interceptSubmit)}>
					{/* You can pass any attribute of <select /> as attributes of the <Field /> */}
					<Field component={FormSelectField} name="prop" label="Select property">
						<option value="opt-1">Option 1</option>
						<option value="opt-2">Option 2</option>
						<option value="opt-3">Option 3</option>
						<option value="opt-4">Option 4</option>
					</Field>
					<button className="btn btn-primary">Submit</button>
				</form>
			);
		};

		const FormWrapper = HOCs.withForm({
			name: "SelectFieldForm",
			required: ["prop"]
		})(Holder);

		return <FormWrapper />;
	});
