import React from "react";
import { Field } from "redux-form";
import { storiesOf } from "@storybook/react";
import { action } from "@storybook/addon-actions";
import { StoreProvider } from "../../_decorators";
import { FormTextField } from "./index";
import { HOCs } from "../../hocs";

storiesOf("FormTextField", module)
	.addDecorator(story => (
		<StoreProvider>
			<div style={{ padding: "30px" }}>{story()}</div>
		</StoreProvider>
	))
	.add("default", () => {
		// eslint-disable-next-line react/prop-types
		const Holder = function({ handleSubmit }) {
			const interceptSubmit = values => {
				action("TextFieldForm submitted")(values);
			};

			return (
				<form onSubmit={handleSubmit(interceptSubmit)}>
					{/* You can pass any attribute of <textarea /> as attributes of the <Field /> */}
					<Field component={FormTextField} name="prop" label="Multi Line Text Property" placeholder="Enter value" />
					<button className="btn btn-primary">Submit</button>
				</form>
			);
		};

		const FormWrapper = HOCs.withForm({
			name: "TextFieldForm",
			required: ["prop"]
		})(Holder);

		return <FormWrapper />;
	});
