import { useEffect } from "react";

/**
 * Allows a component to be aware of window size changes.
 * The passed callback is passed an array which contains the window width and height
 */
export const useWindowSize = callback => {
	const onWindowResized = () => {
		if (callback) callback([window.innerWidth, window.innerHeight]);
	};

	useEffect(() => {
		window.addEventListener("resize", onWindowResized);
		onWindowResized();

		return () => {
			window.removeEventListener("resize", onWindowResized);
		};
	}, []);
};
