import { useWindowSize } from "./use-window-size";

/**
 * Not to be confused with `useWindowSize(cb)`, this hook allows a component to be aware
 * of window size categorizations based on the bootstraps sceen breakpoints.
 *
 * - `Below  576px` - extra small screen size
 * - `576px to 767px` - small screen size
 * - `768px to 991px` - medium screen size
 * - `992px to 1199px` - large screen size
 * - `Above 1200px` - extra large screen size
 *
 * The passed callback is passed an number which represent the index of the screen category.
 * - `0` - extra small screen size
 * - `1` - small screen size
 * - `2` - medium screen size
 * - `3` - large screen size
 * - `4` - extra large screen size
 */

export const useWindowSizes = callback => {
	useWindowSize(([width]) => {
		if (width < 576) callback(0);
		else if (width >= 576 && width < 768) callback(1);
		else if (width >= 768 && width < 992) callback(2);
		else if (width >= 992 && width < 1200) callback(3);
		else callback(4);
	}, []);
};
