import "./index.scss";
import React from "react";
import PT from "prop-types";
import { Link } from "react-router-dom";

export const ListRenderer = ({ items = [], attrs = [], redirect = "", renderCustomData, renderCustomUI, customUIContainerClass = "row" }) => {
	const redirectComponents = redirect.split(":");
	const redirectUrl = redirectComponents[0];
	const redirectAttr = redirectComponents[1];

	return (
		<div className="list-renderer">
			{items.length == 0 && (
				<p className="no-items">
					<small>No items to display</small>
				</p>
			)}

			{items.length > 0 && !renderCustomUI && (
				<table className="table table-hover table-sm">
					<thead>
						<tr>
							{attrs.map((attr, index) => (
								<th key={index}>{attr.label}</th>
							))}
							{redirect && <th />}
						</tr>
					</thead>

					<tbody>
						{items.map((item, itemIndex) => (
							<tr key={itemIndex}>
								{attrs.map((attr, attrIndex) => {
									const customContent = renderCustomData ? renderCustomData(item, attr.value, itemIndex, attrIndex) : null;
									return <td key={"td" + attrIndex}>{customContent || item[attr.value]}</td>;
								})}
								{redirect && (
									<td>
										<Link to={`${redirectUrl}${item[redirectAttr]}`} className="redirect-btn btn btn-link">
											More
										</Link>
									</td>
								)}
							</tr>
						))}
					</tbody>
				</table>
			)}

			{items.length > 0 && renderCustomUI && <div className={customUIContainerClass}>{items.map(item => renderCustomUI(item))}</div>}
		</div>
	);
};

ListRenderer.propTypes = {
	items: PT.array,
	attrs: PT.arrayOf(
		PT.shape({
			label: PT.string,
			value: PT.string
		})
	),
	redirect: PT.string,
	customUIContainerClass: PT.string,
	renderCustomData: PT.func,
	renderCustomUI: PT.func
};
