import React from "react";
import moment from "moment";
import { storiesOf } from "@storybook/react";
import { FontWrapper, Router } from "../_decorators";
import { ListRenderer } from "./index.jsx";

const tableItems = [
	{
		name: "Item 1",
		created_at: "2019-01-01",
		owner_institution_name: "IOI"
	},
	{
		name: "Item 2",
		created_at: "2019-01-01",
		owner_institution_name: "Oasis"
	},
	{
		name: "Item 3",
		created_at: "2018-11-01",
		owner_institution_name: "Modogot"
	}
];

const defaultAttrs = [{ label: "Col#1" }, { label: "Col#2" }, { label: "Col#3" }];

const attrs = [
	{ label: "Item", value: "name" },
	{ label: "Created at", value: "created_at" },
	{ label: "Owner institution", value: "owner_institution_name" }
];

const renderCustomData = (item, value) => {
	if (value == "created_at") return moment(item[value]).format("dddd DD-MMMM-YYYY");
	return <strong>{item[value]}</strong>;
};

const renderCustomUI = item => {
	return (
		<div className="col-12 col-md-4">
			<div className="card">
				<div className="card-header">{item.name}</div>
				<div className="card-body">{item.owner_institution_name}</div>
				<div className="card-footer">{moment(item.created_at).format("Do-MMMM-YYYY")}</div>
			</div>
		</div>
	);
};

storiesOf("List Renderer", module)
	.addDecorator(story => (
		<Router>
			<FontWrapper>{story()}</FontWrapper>
		</Router>
	))
	.add("default", () => <ListRenderer attrs={defaultAttrs} />)
	.add("with items", () => <ListRenderer items={tableItems} attrs={attrs} redirect="/backoffice/institution/show/:created_at" />)
	.add("with custom data render", () => (
		<ListRenderer items={tableItems} attrs={attrs} redirect="/backoffice/institution/show/:created_at" renderCustomData={renderCustomData} />
	))
	.add("with custom UI render", () => {
		return <ListRenderer items={tableItems} renderCustomUI={renderCustomUI} />;
	})
	.add("with no redirect", () => <ListRenderer attrs={attrs} items={tableItems} render={renderCustomData} />);
