import "./index.scss";
import React from "react";
import PropTypes from "prop-types";

export function RadioGroup({ label, options, value, orientation = "horizontal", noLabel, onChange }) {
	const interceptOnKeyDown = e => {
		const selectedOptionIndex = (() => {
			for (var i = 0; i < options.length; i++) {
				const option = options[i];
				if (value == option.value) return i;
			}

			return -1;
		})();

		switch (e.keyCode) {
			case 37: // Left arrow
				onChange(options[Math.max(0, Math.min(selectedOptionIndex - 1, options.length - 1))].value);
				break;
			case 39: // Right arrow
				onChange(options[Math.max(0, Math.min(selectedOptionIndex + 1, options.length - 1))].value);
				break;
		}
	};

	return (
		<div className={`radio-group ${orientation == "vertical" ? "vertical" : ""}`} tabIndex={0} onKeyDown={interceptOnKeyDown}>
			{!noLabel && <label className="group-label">{label}</label>}

			{options.map(({ label, value: optionValue }, i) => {
				const checked = value == optionValue;

				return (
					<label key={`radio-field${i}`} className="radio-field" onClick={() => onChange(optionValue)}>
						<span className={`indicator ${checked ? "checked" : ""}`} />
						<label>{label}</label>
					</label>
				);
			})}
		</div>
	);
}

RadioGroup.propTypes = {
	label: PropTypes.string,
	options: PropTypes.arrayOf(
		PropTypes.shape({
			label: PropTypes.string,
			value: PropTypes.any
		})
	),
	value: PropTypes.string,
	orientation: PropTypes.oneOf(["horizontal", "vertical"]),
	noLabel: PropTypes.bool,
	onChange: PropTypes.func
};
