import React, { useState } from "react";
import { storiesOf } from "@storybook/react";
import { action } from "@storybook/addon-actions";
import { RadioGroup } from "./index";

const withValueProps = {
	label: "Order type",
	options: [
		{ label: "Good till closed", value: "good_till_closed" },
		{ label: "Has expiry", value: "has_expiry" },
		{ label: "osnv", value: "kiiSf-qwe" },
		{ label: "ons onk", value: "kpsfv-ef" }
	]
};

const isVerticalProps = {
	...withValueProps,
	orientation: "vertical"
};

storiesOf("Radio Group", module)
	.addDecorator(story => <div style={{ padding: "30px" }}>{story()}</div>)
	.add("default", () => {
		const RadioGroupHolder = function() {
			const [value, setValue] = useState("");
			const onSetValue = value => {
				setValue(value);
				action("Changed")(value);
			};
			return <RadioGroup {...withValueProps} value={value} onChange={onSetValue} />;
		};

		return <RadioGroupHolder />;
	})
	.add("is vertical", () => {
		const RadioGroupHolder = function() {
			const [value, setValue] = useState("");
			const onSetValue = value => {
				setValue(value);
				action("Changed")(value);
			};
			return <RadioGroup {...isVerticalProps} value={value} onChange={onSetValue} />;
		};

		return <RadioGroupHolder />;
	})
	.add("with no label", () => {
		const RadioGroupHolder = function() {
			const [value, setValue] = useState("");
			const onSetValue = value => {
				setValue(value);
				action("Changed")(value);
			};
			return <RadioGroup {...isVerticalProps} value={value} onChange={onSetValue} noLabel />;
		};

		return <RadioGroupHolder />;
	});
