import "./index.scss";
import PT from "prop-types";
import React, { useState, Children } from "react";

export const Tab = ({ labels, children, index, setIndex }) => {
	const isControlled = index != null && setIndex != null;
	const [internalIndex, setInternalIndex] = useState(0);
	const childArray = Children.toArray(children);

	const onLabelClicked = index => {
		if (isControlled) setIndex(index);
		else setInternalIndex(index);
	};

	return (
		<div className="tab">
			<div className="tab-header">
				<div className="tab-header-content">
					{labels.map((label, i) => (
						<span key={i} className={(index || internalIndex) == i ? "active" : ""} onClick={() => onLabelClicked(i)}>
							{label}
						</span>
					))}
				</div>
			</div>

			<div className="tab-body">{childArray[isControlled ? index : internalIndex]}</div>
		</div>
	);
};

Tab.propTypes = {
	labels: PT.array,
	children: PT.any,
	index: PT.number,
	setIndex: PT.func
};
